@@ -47,7 +47,8 @@ class Data(Group):
         Group.__init__(self, *args, **kwargs)
         # populate axes, constants from attrs string
         for identifier in self.attrs.get("axes", []):
-            identifier = identifier.decode()
+            if hasattr(identifier, "decode"):
+                identifier = identifier.decode()
             expression, units = identifier.split("{")
             units = units.replace("}", "").strip()
             if units == "None":
@@ -59,7 +60,8 @@ class Data(Group):
             axis = Axis(self, expression, units)
             self._axes.append(axis)
         for identifier in self.attrs.get("constants", []):
-            identifier = identifier.decode()
+            if hasattr(identifier, "decode"):
+                identifier = identifier.decode()
             expression, units = identifier.split("{")
             units = units.replace("}", "").strip()
             if units == "None":
@@ -70,12 +72,13 @@ class Data(Group):
             const = Constant(self, expression, units)
             self._constants.append(const)
         self._current_axis_identities_in_natural_namespace = []
-        self._on_constants_updated()
-        self._on_axes_updated()
-        # the following are populated if not already recorded
-        self.channel_names
-        self.source
-        self.variable_names
+        if self.file.mode is not None and self.file.mode != "r":
+            self._on_constants_updated()
+            self._on_axes_updated()
+            # the following are populated if not already recorded
+            self.channel_names
+            self.source
+            self.variable_names
 
     def __repr__(self) -> str:
         return "<WrightTools.Data '{0}' {1} at {2}>".format(
@@ -218,7 +221,7 @@ class Data(Group):
         Propagates updated axes properly.
         """
         # update attrs
-        self.attrs["axes"] = [a.identity.encode() for a in self._axes]
+        self.attrs["axes"] = np.array([a.identity.encode() for a in self._axes], dtype="S")
         # remove old attributes
         while len(self._current_axis_identities_in_natural_namespace) > 0:
             key = self._current_axis_identities_in_natural_namespace.pop(0)
@@ -238,7 +241,9 @@ class Data(Group):
         Propagates updated constants properly.
         """
         # update attrs
-        self.attrs["constants"] = [a.identity.encode() for a in self._constants]
+        self.attrs["constants"] = np.array(
+            [a.identity.encode() for a in self._constants], dtype="S"
+        )
 
     def _print_branch(self, prefix, depth, verbose):
         def print_leaves(prefix, lis, vline=True):
@@ -386,6 +391,9 @@ class Data(Group):
         for i in at.keys():
             if type(i) == int:
                 removed_shape[i] = 1
+        for ax in kept_axes:
+            if ax.shape.count(1) == ax.ndim - 1:
+                removed_shape[ax.shape.index(ax.size)] = 1
         removed_shape = tuple(removed_shape)
         # iterate
         i = 0
@@ -537,7 +545,7 @@ class Data(Group):
         resultant : tuple of int
             The resultant shape after the moment operation.
             By default, it is intuited by the axis along which the moment is being taken.
-            This default only works if that axis is 1D, so resultant is required if a 
+            This default only works if that axis is 1D, so resultant is required if a
             multidimensional axis is passed as the first argument.
             The requirement of monotonicity applies on a per pixel basis.
 
@@ -770,11 +778,9 @@ class Data(Group):
             Convert a single axis object to compatable units. Call on an
             axis object in data.axes.
         """
-        # get kind of units
-        units_kind = wt_units.kind(destination_units)
         # apply to all compatible axes
         for axis in self.axes:
-            if axis.units_kind == units_kind:
+            if wt_units.is_valid_conversion(axis.units, destination_units):
                 orig = axis.units
                 axis.convert(destination_units, convert_variables=convert_variables)
                 if verbose:
@@ -785,7 +791,7 @@ class Data(Group):
                     )
         # apply to all compatible constants
         for constant in self.constants:
-            if constant.units_kind == units_kind:
+            if wt_units.is_valid_conversion(constant.units, destination_units):
                 orig = constant.units
                 constant.convert(destination_units, convert_variables=convert_variables)
                 if verbose:
@@ -796,7 +802,7 @@ class Data(Group):
                     )
         if convert_variables:
             for var in self.variables:
-                if wt_units.kind(var.units) == units_kind:
+                if wt_units.is_valid_conversion(var.units, destination_units):
                     orig = var.units
                     var.convert(destination_units)
                     if verbose:
@@ -1129,7 +1135,15 @@ class Data(Group):
         else:
             points = wt_units.converter(points, input_units, variable.units)
         # construct new data object
-        special = ["name", "axes", "constants", "channel_names", "variable_names"]
+        special = [
+            "name",
+            "axes",
+            "constants",
+            "channel_names",
+            "variable_names",
+            "filepath",
+            "edit_local",
+        ]
         kwargs = {k: v for k, v in self.attrs.items() if k not in special}
         if name is None:
             name = "{0}_{1}_mapped".format(self.natural_name, variable.natural_name)
@@ -1322,7 +1336,7 @@ class Data(Group):
 
     def prune(self, keep_channels=True, *, verbose=True):
         """Remove unused variables and (optionally) channels from the Data object.
-            
+
         Unused variables are those that are not included in either axes or constants.
         Unused channels are those not specified in keep_channels, or the first channel.
 
@@ -1666,7 +1680,7 @@ class Data(Group):
 
         self.transform(expression)
         if units:
-            self.convert(units)
+            self.convert(units, verbose=False)
 
         try:
             positions = [-np.inf] + sorted(list(positions)) + [np.inf]
@@ -1845,7 +1859,7 @@ class Data(Group):
             Expression for the new constant.
         verbose : boolean (optional)
             Toggle talkback. Default is True
-            
+
         See Also
         --------
         set_constants
@@ -1875,7 +1889,7 @@ class Data(Group):
             Expression for the new constant.
         verbose : boolean (optional)
             Toggle talkback. Default is True
-            
+
         See Also
         --------
         set_constants
